@@ -336,7 +336,8 @@ static void nma_about_cb (GtkMenuItem *mi, NMApplet *applet)
 
 	about_dialog = gnome_about_new (_("NetworkManager Applet"),
 	                                VERSION,
-	                                _("Copyright \xc2\xa9 2004-2005 Red Hat, Inc."),
+	                                _("Copyright \xc2\xa9 2004-2006 Red Hat, Inc.\n"
+							    "Copyright \xc2\xa9 2005-2006 Novell, Inc."),
 	                                _("Notification area applet for managing your network devices and connections."),
 	                                authors,
 	                                documenters,
@@ -361,7 +362,8 @@ static void nma_about_cb (GtkMenuItem *mi, NMApplet *applet)
 	gtk_show_about_dialog (NULL,
 	                       "name", _("NetworkManager Applet"),
 	                       "version", VERSION,
-	                       "copyright", _("Copyright \xc2\xa9 2004-2005 Red Hat, Inc."),
+	                       "copyright", _("Copyright \xc2\xa9 2004-2005 Red Hat, Inc.\n"
+					                  "Copyright \xc2\xa9 2005-2006 Novell, Inc."),
 	                       "comments", _("Notification area applet for managing your network devices and connections."),
 	                       "website", "http://www.gnome.org/projects/NetworkManager/",
 	                       "authors", authors,
@@ -374,86 +376,6 @@ static void nma_about_cb (GtkMenuItem *mi, NMApplet *applet)
 }
 
 
-#define AUTOSTART_ENABLE_STR		"X-GNOME-Autostart-enabled=true"
-#define AUTOSTART_ENABLE_STR_LEN	30
-#define AUTOSTART_DISABLE_STR		"X-GNOME-Autostart-enabled=false"
-#define AUTOSTART_DISABLE_STR_LEN	31
-static void G_GNUC_NORETURN nma_remove_cb (GtkMenuItem *mi, NMApplet *applet)
-{
-	char			*src;
-	char			*dir;
-	char			*file;
-	const char	*sub;
-	gsize		src_len;
-	GtkWidget 	*dialog;
-
-	/*
-	 * Give the user the option of disabling autostart, if it is enabled.  Autostart is in
-	 * use if there is an nm-applet.desktop in either the system wide or the per-user
-	 * autostart directory and it has "X-GNOME-Autostart-enabled" set to "true".  To disable
-	 * autostart, we (re)write the autostart file to the per-user location, with the
-	 * autostart option set to "false".
-	 */
-
-	dir = g_strdup_printf ("%s/.config/autostart", g_get_home_dir ());
-	file = g_strdup_printf ("%s/nm-applet.desktop", dir);
-
-	/*
-	 * Figure out what our source file is.  Try to use the user's nm-applet.desktop, first.
-	 * If it does not exist, we use the system-wide autostart file.
-	 */
-	if (!g_file_get_contents (file, &src, &src_len, NULL))
-		if (!g_file_get_contents (AUTOSTARTDIR"/nm-applet.desktop", &src, &src_len, NULL))
-			goto out_free_file;
-
-	/* If autostart is explicitly disabled or not explicitly enabled, we are done. */
-	if (strstr (src, AUTOSTART_DISABLE_STR))
-		goto out_free_src;
-	sub = strstr (src, AUTOSTART_ENABLE_STR);
-	if (!sub)
-		goto out_free_src;
-
-	dialog = gtk_message_dialog_new_with_markup (NULL, 0, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO,
-										"<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
-										_("Stop automatically running the networking applet?"),
-										_("The networking applet will now terminate, but will automatically launch the next time you login.  Would you like to stop automatically running the networking applet on login?"));
-	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES)
-	{
-		char			*dst;
-		gsize		dst_len;
-		gsize		sub_len;
-
-		src_len += 1;
-		dst_len = src_len + 1;
-		dst = g_malloc (dst_len);
-		sub_len = sub - src;
-
-		/* memcpy the first chunk, write in our updated string, and memcpy the remaining bytes */
-		memcpy (dst, src, sub_len);
-		g_strlcpy (dst + sub_len, AUTOSTART_DISABLE_STR, dst_len - sub_len);
-		memcpy (dst + sub_len + AUTOSTART_DISABLE_STR_LEN,
-			   sub + AUTOSTART_ENABLE_STR_LEN,
-			   src_len - sub_len - AUTOSTART_ENABLE_STR_LEN);
-		dst[dst_len-1] = '\0';
-
-		g_mkdir_with_parents (dir, 0750);
-		g_file_set_contents (file, dst, dst_len, NULL);
-
-		g_free (dst);
-	}
-
-	gtk_widget_destroy (dialog);
-
-out_free_src:
-	g_free (src);
-out_free_file:
-	g_free (file);
-	g_free (dir);
-
-	nma_destroy (applet);
-}
-
-
 #ifndef ENABLE_NOTIFY
 /*
  * nma_show_vpn_failure_dialog
@@ -1665,6 +1587,7 @@ static void nma_add_networks_helper (NetworkDevice *dev, WirelessNetwork *net, g
 	AddNetworksCB *	cb_data = (AddNetworksCB *)user_data;
 	NMNetworkMenuItem *	item;
 	GtkCheckMenuItem *	gtk_item;
+	NMApplet *		applet;
 
 	g_return_if_fail (dev != NULL);
 	g_return_if_fail (net != NULL);
@@ -1672,22 +1595,23 @@ static void nma_add_networks_helper (NetworkDevice *dev, WirelessNetwork *net, g
 	g_return_if_fail (cb_data->menu != NULL);
 	g_return_if_fail (cb_data->applet != NULL);
 
-	item = network_menu_item_new (cb_data->applet->encryption_size_group);
+	applet = cb_data->applet;
+	item = network_menu_item_new (applet->encryption_size_group);
 	gtk_item = network_menu_item_get_check_item (item);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (cb_data->menu), GTK_WIDGET (gtk_item));
-	if (   (cb_data->applet->nm_state == NM_STATE_CONNECTED)
-	    || (cb_data->applet->nm_state == NM_STATE_CONNECTING))
+	if (   (applet->nm_state == NM_STATE_CONNECTED)
+	    || (applet->nm_state == NM_STATE_CONNECTING))
 	{
 		if (network_device_get_active (dev) && wireless_network_get_active (net))
 			gtk_check_menu_item_set_active (gtk_item, TRUE);
 	}
-	network_menu_item_update (item, net, cb_data->has_encrypted);
+	network_menu_item_update (applet, item, net, cb_data->has_encrypted);
 
 	g_object_set_data (G_OBJECT (gtk_item), "network", g_strdup (wireless_network_get_essid (net)));
 	g_object_set_data (G_OBJECT (gtk_item), "device", g_strdup (network_device_get_nm_path (dev)));
 	g_object_set_data (G_OBJECT (gtk_item), "nm-item-data", item);
-	g_signal_connect (G_OBJECT (gtk_item), "activate", G_CALLBACK (nma_menu_item_activate), cb_data->applet);
+	g_signal_connect (G_OBJECT (gtk_item), "activate", G_CALLBACK (nma_menu_item_activate), applet);
 
 	gtk_widget_show (GTK_WIDGET (gtk_item));
 }
@@ -2283,13 +2207,6 @@ static GtkWidget *nma_context_menu_create (NMApplet *applet)
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 
-	/* Quit */
-	menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Remove"));
-	g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK (nma_remove_cb), applet);
-	image = gtk_image_new_from_stock (GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
-
 	gtk_widget_show_all (menu);
 
 	return menu;
@@ -2538,6 +2455,10 @@ static void G_GNUC_NORETURN nma_destroy (NMApplet *applet)
 	nma_icons_free (applet);
 
 	nmi_passphrase_dialog_destroy (applet);
+#ifdef ENABLE_NOTIFY
+	notify_notification_close (applet->notification, NULL);
+	g_object_unref (applet->notification);
+#endif
 
 	if (applet->redraw_timeout_id > 0)
 	{
@@ -2579,6 +2500,10 @@ static GtkWidget * nma_get_instance (NMApplet *applet)
 	applet->nm_state = NM_STATE_DISCONNECTED;
 	applet->tooltips = NULL;
 	applet->passphrase_dialog = NULL;
+#ifdef ENABLE_NOTIFY
+	applet->notification = NULL;
+#endif
+
 	applet->glade_file = g_build_filename (GLADEDIR, "applet.glade", NULL);
 	if (!applet->glade_file || !g_file_test (applet->glade_file, G_FILE_TEST_IS_REGULAR))
 	{
@@ -2625,7 +2550,7 @@ static GtkWidget * nma_get_instance (NMApplet *applet)
 
 static void nma_icons_free (NMApplet *applet)
 {
-	gint i,j;
+	int i;
 
 	g_object_unref (applet->no_connection_icon);
 	g_object_unref (applet->wired_icon);
@@ -2639,17 +2564,49 @@ static void nma_icons_free (NMApplet *applet)
 	g_object_unref (applet->wireless_100_icon);
 
 	for (i = 0; i < NUM_CONNECTING_STAGES; i++)
+	{
+		int j;
+
 		for (j = 0; j < NUM_CONNECTING_FRAMES; j++)
 			g_object_unref (applet->network_connecting_icons[i][j]);
+	}
 
 	for (i = 0; i < NUM_VPN_CONNECTING_FRAMES; i++)
 		g_object_unref (applet->vpn_connecting_icons[i]);
 }
 
+static void nma_icons_zero (NMApplet *applet)
+{
+	int i;
+
+	applet->no_connection_icon = NULL;
+	applet->wired_icon = NULL;
+	applet->adhoc_icon = NULL;
+	applet->vpn_lock_icon = NULL;
+
+	applet->wireless_00_icon = NULL;
+	applet->wireless_25_icon = NULL;
+	applet->wireless_50_icon = NULL;
+	applet->wireless_75_icon = NULL;
+	applet->wireless_100_icon = NULL;
+
+	for (i = 0; i < NUM_CONNECTING_STAGES; i++)
+	{
+		int j;
+
+		for (j = 0; j < NUM_CONNECTING_FRAMES; j++)
+			applet->network_connecting_icons[i][j] = NULL;
+	}
+
+	for (i = 0; i < NUM_VPN_CONNECTING_FRAMES; i++)
+		applet->vpn_connecting_icons[i] = NULL;
+
+}
+
 #define ICON_LOAD(x, y)	\
 	{		\
 		GError *err = NULL; \
-		x = gtk_icon_theme_load_icon (icon_theme, y, icon_size, 0, &err); \
+		x = gtk_icon_theme_load_icon (icon_theme, y, 22, 0, &err); \
 		if (x == NULL) { \
 			success = FALSE; \
 			g_warning ("Icon %s missing: %s", y, err->message); \
@@ -2661,12 +2618,14 @@ static void nma_icons_free (NMApplet *applet)
 static gboolean
 nma_icons_load_from_disk (NMApplet *applet, GtkIconTheme *icon_theme)
 {
-	char *	name;
-	int		i, j;
-	gboolean	success = FALSE;
+	int		i;
+	gboolean	success;
 
-	/* Assume icons are square */
-	gint icon_size = 22;
+	/*
+	 * NULL out the icons, so if we error and call nma_icons_free(), we don't hit stale
+	 * data on the not-yet-reached icons.  This can happen off nma_icon_theme_changed().
+	 */
+	nma_icons_zero (applet);
 
 	ICON_LOAD(applet->no_connection_icon, "nm-no-connection");
 	ICON_LOAD(applet->wired_icon, "nm-device-wired");
@@ -2681,8 +2640,12 @@ nma_icons_load_from_disk (NMApplet *applet, GtkIconTheme *icon_theme)
 
 	for (i = 0; i < NUM_CONNECTING_STAGES; i++)
 	{
+		int j;
+
 		for (j = 0; j < NUM_CONNECTING_FRAMES; j++)
 		{
+			char *name;
+
 			name = g_strdup_printf ("nm-stage%02d-connecting%02d", i+1, j+1);
 			ICON_LOAD(applet->network_connecting_icons[i][j], name);
 			g_free (name);
@@ -2691,6 +2654,8 @@ nma_icons_load_from_disk (NMApplet *applet, GtkIconTheme *icon_theme)
 
 	for (i = 0; i < NUM_VPN_CONNECTING_FRAMES; i++)
 	{
+		char *name;
+
 		name = g_strdup_printf ("nm-vpn-connecting%02d", i+1);
 		ICON_LOAD(applet->vpn_connecting_icons[i], name);
 		g_free (name);
