@@ -215,8 +215,6 @@ void nm_system_update_dns (void)
  */
 void nm_system_restart_mdns_responder (void)
 {
-	/* for GWARE at least */
-	nm_spawn_process("/etc/rc.d/rc.howl restart");
 }
 
 
@@ -431,7 +429,7 @@ gboolean nm_system_should_modify_resolv_conf (void)
  * Return a user-provided or system-mandated MTU for this device or zero if
  * no such MTU is provided.
  */
-unsigned int nm_system_get_mtu (NMDevice *dev)
+guint32 nm_system_get_mtu (NMDevice *dev)
 {
 	return 0;
 }
